@@ -9,7 +9,7 @@ from uplogic.animation import ULActionSystem
 from uplogic.animation.actionsystem import get_action_system
 from uplogic.events import schedule
 import bpy
-from uplogic.utils import clamp
+from uplogic.utils import clamp, debug
 
 
 PLAY_MODES = {
@@ -17,12 +17,14 @@ PLAY_MODES = {
     'pingpong': logic.KX_ACTION_MODE_PING_PONG,
     'loop': logic.KX_ACTION_MODE_LOOP
 }
+"""Available play modes of [`"play"`, `"pingpong"`, `"loop"`]"""
 
 
 BLEND_MODES = {
     'blend': logic.KX_ACTION_BLEND_BLEND,
     'add': logic.KX_ACTION_BLEND_ADD
 }
+"""Available blending modes of [`"blend"`, `"add"`]"""
 
 
 ACTION_STARTED = 'ACTION_STARTED'
@@ -30,7 +32,10 @@ ACTION_FINISHED = 'ACTION_FINISHED'
 
 
 class ULAction():
-    '''Wrapper class for animated actions that provides additional parameters
+    '''
+    [DEPRECATED]
+
+    Wrapper class for animated actions that provides additional parameters
     and quick access properties.
 
     :param `game_object`: The `KX_GameObject` on which to play the action.
@@ -65,9 +70,9 @@ class ULAction():
         speed: float = 1,
         intensity: float = 1,
         blend_mode: str = 'blend',
-        keep: bool = False,
-        overwrite: bool = False
+        keep: bool = False
     ):
+        debug('ULAction class will be renamed to "Action" in future releases!')
         self._fps_factor = bpy.context.scene.render.fps / 60
         self._locked = False
         self._speed = speed
@@ -99,14 +104,13 @@ class ULAction():
         '''Blending Mode of the animation.'''
         if layer == -1:
             ULActionSystem.find_free_layer(self)
-        elif ULActionSystem.check_layer(self) and not overwrite:
+        elif ULActionSystem.check_layer(self):
             self.finished = True
             return
         layer = self.layer
         same_action = game_object.getActionName(layer) == action_name
         self.on_start()
-        self.restart_flag = False
-        if (not same_action and self.is_playing) or overwrite:
+        if (not same_action and self.is_playing):
             game_object.stopAction(layer)
         if not (self.is_playing or same_action):
             game_object.playAction(
@@ -154,7 +158,7 @@ class ULAction():
         return -1
 
     @frame.setter
-    def frame(self, value):
+    def frame(self, value: float):
         self.game_object.setActionFrame(value, self.layer)
 
     @property
@@ -164,7 +168,7 @@ class ULAction():
         return self._intensity
 
     @intensity.setter
-    def intensity(self, value):
+    def intensity(self, value: float):
         if not self.is_playing:
             return
         if not self.is_playing or value == self._intensity:
@@ -178,13 +182,13 @@ class ULAction():
         return self._speed
 
     @speed.setter
-    def speed(self, value):
+    def speed(self, value: float):
         if value < 0.00000000001:
             value = 0.00000000001
         if not self.is_playing or value == self._speed:
             return
-        self._restart_action()
         self._speed = value
+        self._restart_action()
 
     def _restart_action(self):
         '''Restart action to use updated values.
@@ -304,20 +308,20 @@ class ULAction():
             blend_mode=self.blend_mode
         )
 
-    def randomize_frame(self, min=None, max=None):
+    def randomize_frame(self, min: float = -1, max: float = -1):
         '''Randomize the frame of this animation.
 
         :param `min`: Min range of randomization (Optional).
         :param `max`: Max range of randomization (Optional).
         '''
-        if min is None:
+        if min == -1:
             min = self.start_frame
-        if max is None:
+        if max == -1:
             max = self.end_frame
         frame = randint(min, max)
         self.frame = frame
 
-    def randomize_speed(self, min=.9, max=1.1):
+    def randomize_speed(self, min: float = .9, max: float = 1.1):
         '''Randomize the speed of this animation.
 
         :param `min`: Min range of randomization (Optional, default 0.9).
@@ -326,7 +330,30 @@ class ULAction():
         delta = max - min
         self.speed = min + (delta * random())
 
-    def set_frame(self, frame):
+    def set_frame(self, frame: float):
         '''Set the frame of this action.
         '''
         self.frame = frame
+
+class Action(ULAction):
+    '''Wrapper class for animated actions that provides additional parameters
+    and quick access properties.
+
+    :param `game_object`: The `KX_GameObject` on which to play the action.
+    :param `action_name`: The name of the action  of `bpy.data.actions`.
+    :param `start_frame`: The first frame of the action.
+    :param `end_frame`: The last frame of the action.
+    :param `layer`: The layer on which to play the action. Leave at -1 for
+    auto-selection.
+    :param `priority`: The priority with which to play the action (only relevant
+    for actions on the same layer).
+    :param `blendin`: Use this many frames to "blend into" the animation.
+    :param `play_mode`: Mode of playback of [`'play'`, `'loop'`, `'pingpong'`].
+    :param `speed`: Playback speed.
+    :param `intensity`: "Intensity" of the action; Use this to blend
+    animations on different layers together.
+    :param `blend_mode`: Mode of blending of [`'blend'`, `'add'`]
+    :param `keep`: Whether to keep the animation cached after playback has
+    finished. This is useful for setting animation frames regardless of the
+    action state.'''
+    pass
\ No newline at end of file
