@@ -5,9 +5,12 @@ import time
 
 
 class ULSequence():
-    '''Play an image animation through a material node.
-    
+    '''[DEPRECATED]
+
+    Play an image animation through a material node.
+
     :param `material`: Name of the material to play the animation on.
+    Each Object with this material applied will play the animation.
     :param `node`: Name of the node the image animation is loaded on.
     :param `start_frame`: Starting frame of the animation.
     :param `end_frame`: End frame of the animation.
@@ -25,23 +28,32 @@ class ULSequence():
         mode: str = 'play'
     ) -> None:
         self.material = material
+        """The material this sequence is played on."""
         self.node = node
+        """Name of the node the image animation is loaded on."""
         self.start_frame = start_frame
+        """Starting frame of the animation."""
         self.end_frame = end_frame
+        """End frame of the animation."""
         self.fps = fps
+        """Frames per second."""
         self.mode = PLAY_MODES.get(mode, 0)
+        """Animation mode, `str` of [`play`, `loop`, `pingpong`]"""
         self.time = 0.0
+        """Animation progress."""
         self.frame = 0
-        self.initialized = False
-        self.reverse = False
-        self.running = True
+        """Current frame of the animation."""
+        self.on_start = False
+        """`True` when animation started."""
+        self.on_finish = False
+        """`True` when animation finished this frame."""
+        self._initialized = False
+        self._reverse = False
+        self._running = True
         self._consumed = False
-        self.active = True
         self._pause = False
         self._time_then = time.time()
-        self.on_start = False
-        self.on_finish = False
-        self.player = (
+        self._player = (
             bpy.data.materials[material]
             .node_tree
             .nodes[node]
@@ -57,21 +69,21 @@ class ULSequence():
     def pause(self):
         '''Pause this animation.'''
         self._pause = True
-        self.running = False
+        self._running = False
 
     def restart(self):
         '''Restart this animation.'''
-        self.initialized = False
+        self._initialized = False
 
     def unpause(self):
         '''Continue this animation.'''
         self._pause = False
-        self.running = True
+        self._running = True
 
     def update(self):
         '''This is called each frame.'''
         now = time.time()
-        player = self.player
+        player = self._player
         self.time += now - self._time_then
         self._time_then = now
         fps = self.fps
@@ -83,12 +95,12 @@ class ULSequence():
         if self._pause:
             return
         play_mode = self.mode
-        running = self.running
-        start_frame = self.end_frame if self.reverse else self.start_frame
-        end_frame = self.start_frame if self.reverse else self.end_frame
-        if not self.initialized:
+        running = self._running
+        start_frame = self.end_frame if self._reverse else self.start_frame
+        end_frame = self.start_frame if self._reverse else self.end_frame
+        if not self._initialized:
             player.frame_offset = round(start_frame)
-            self.initialized = True
+            self._initialized = True
         inverted = (start_frame > end_frame)
         frame = self.frame = player.frame_offset
         reset_cond = (frame <= end_frame) if inverted else (frame >= end_frame)
@@ -101,12 +113,12 @@ class ULSequence():
         start_cond = frame > start_frame if inverted else frame < start_frame
 
         if start_cond:
-            self.running = True
+            self._running = True
             player.frame_offset = round(start_frame)
         frame = player.frame_offset
         run_cond = (frame > end_frame) if inverted else (frame < end_frame)
         if run_cond:
-            self.running = True
+            self._running = True
             s = round(speed)
             if inverted:
                 if frame - s < end_frame:
@@ -135,6 +147,20 @@ class ULSequence():
         elif play_mode == 1:
             player.frame_offset = round(end_frame) if inverted else round(start_frame)
         elif play_mode == 2:
-            self.reverse = not self.reverse
+            self._reverse = not self._reverse
         else:
             self.stop()
+
+
+class Sequence(ULSequence):
+    '''Play an image animation through a material node.
+
+    :param `material`: Name of the material to play the animation on.
+    Each Object with this material applied will play the animation.
+    :param `node`: Name of the node the image animation is loaded on.
+    :param `start_frame`: Starting frame of the animation.
+    :param `end_frame`: End frame of the animation.
+    :param `fps`: Frames per second.
+    :param `mode`: Animation mode, `str` of [`play`, `loop`, `pingpong`]
+    '''
+    pass
